﻿function Import-NavAdminTool
{
    [CmdletBinding()]
    param (
        [parameter(Mandatory=$false,ValueFromPipeline=$true)]
        [string]$navInstallationDirectory = 'C:\Program Files\Microsoft Dynamics NAV\71\Service'       
    )
    PROCESS {
        Write-Verbose "Checking if NavAdminTools are already imported..."    
        if ((Get-Module -Name "NavAdminTool" -ErrorAction SilentlyContinue) -eq $null)
        {
            Write-Verbose "Importing NavAdminTools..."            
            $navAdminToolPath = Join-Path $navInstallationDirectory 'NavAdminTool.ps1'
            if (Test-Path $navAdminToolPath)
            {
                Import-Module $navAdminToolPath
            }
            else
            {
                $navAdminToolPath = Join-Path $navInstallationDirectory 'Microsoft.Dynamics.Nav.Management.dll'
                Import-Module $navAdminToolPath
            }
        }
        else
        {
            Write-Verbose "NavAdminTools are already imported"
        }
    }
}

Export-ModuleMember -Function Import-NavAdminTool
# SIG # Begin signature block
# MIILrwYJKoZIhvcNAQcCoIILoDCCC5wCAQExCzAJBgUrDgMCGgUAMGkGCisGAQQB
# gjcCAQSgWzBZMDQGCisGAQQBgjcCAR4wJgIDAQAABBAfzDtgWUsITrck0sYpfvNR
# AgEAAgEAAgEAAgEAAgEAMCEwCQYFKw4DAhoFAAQUSwBPQbeqZxOyoQKlAD7by4y9
# 5vqgggkRMIIEKDCCAxCgAwIBAgILBAAAAAABL07hNVwwDQYJKoZIhvcNAQEFBQAw
# VzELMAkGA1UEBhMCQkUxGTAXBgNVBAoTEEdsb2JhbFNpZ24gbnYtc2ExEDAOBgNV
# BAsTB1Jvb3QgQ0ExGzAZBgNVBAMTEkdsb2JhbFNpZ24gUm9vdCBDQTAeFw0xMTA0
# MTMxMDAwMDBaFw0xOTA0MTMxMDAwMDBaMFExCzAJBgNVBAYTAkJFMRkwFwYDVQQK
# ExBHbG9iYWxTaWduIG52LXNhMScwJQYDVQQDEx5HbG9iYWxTaWduIENvZGVTaWdu
# aW5nIENBIC0gRzIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCyTxTn
# EL7XJnKrNpfvU79ChF5Y0Yoo/ENGb34oRFALdV0A1zwKRJ4gaqT3RUo3YKNuPxL6
# bfq2RsNqo7gMJygCVyjRUPdhOVW4w+ElhlI8vwUd17Oa+JokMUnVoqni05GrPjxz
# 7/Yp8cg10DB7f06SpQaPh+LO9cFjZqwYaSrBXrta6G6V/zuAYp2Zx8cvZtX9YhqC
# VVrG+kB3jskwPBvw8jW4bFmc/enWyrRAHvcEytFnqXTjpQhU2YM1O46MIwx1tt6G
# Sp4aPgpQSTic0qiQv5j6yIwrJxF+KvvO3qmuOJMi+qbs+1xhdsNE1swMfi9tBoCi
# dEC7tx/0O9dzVB/zAgMBAAGjgfowgfcwDgYDVR0PAQH/BAQDAgEGMBIGA1UdEwEB
# /wQIMAYBAf8CAQAwHQYDVR0OBBYEFAhu2Lacir/tPtfDdF3MgB+oL1B6MEcGA1Ud
# IARAMD4wPAYEVR0gADA0MDIGCCsGAQUFBwIBFiZodHRwczovL3d3dy5nbG9iYWxz
# aWduLmNvbS9yZXBvc2l0b3J5LzAzBgNVHR8ELDAqMCigJqAkhiJodHRwOi8vY3Js
# Lmdsb2JhbHNpZ24ubmV0L3Jvb3QuY3JsMBMGA1UdJQQMMAoGCCsGAQUFBwMDMB8G
# A1UdIwQYMBaAFGB7ZhpFDZfKiVAvfQTNNKj//P1LMA0GCSqGSIb3DQEBBQUAA4IB
# AQAiXMXdPfQLcNjj9efFjgkBu7GWNlxaB63HqERJUSV6rg2kGTuSnM+5Qia7O2yX
# 58fOEW1okdqNbfFTTVQ4jGHzyIJ2ab6BMgsxw2zJniAKWC/wSP5+SAeq10NYlHNU
# BDGpeA07jLBwwT1+170vKsPi9Y8MkNxrpci+aF5dbfh40r5JlR4VeAiR+zTIvoSt
# vODG3Rjb88rwe8IUPBi4A7qVPiEeP2Bpen9qA56NSvnwKCwwhF7sJnJCsW3LZMMS
# jNaES2dBfLEDF3gJ462otpYtpH6AA0+I98FrWkYVzSwZi9hwnOUtSYhgcqikGVJw
# Q17a1kYDsGgOJO9K9gslJO8kMIIE4TCCA8mgAwIBAgISESGBEchVFJI+pYM5gzc8
# moWnMA0GCSqGSIb3DQEBBQUAMFExCzAJBgNVBAYTAkJFMRkwFwYDVQQKExBHbG9i
# YWxTaWduIG52LXNhMScwJQYDVQQDEx5HbG9iYWxTaWduIENvZGVTaWduaW5nIENB
# IC0gRzIwHhcNMTQwMjI2MTUyOTM3WhcNMTUwMjI3MTUyOTM3WjB3MQswCQYDVQQG
# EwJJUzESMBAGA1UECBMJUmV5a2phdmlrMRIwEAYDVQQHEwlSZXlramF2aWsxEDAO
# BgNVBAoTB0FkdmFuaWExHDAaBgNVBAsTE0R5bmFtaWNzIE5hdiBUaHJvdW4xEDAO
# BgNVBAMTB0FkdmFuaWEwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDT
# fStE3keO1451Z+7xOdF8us3flCiSj9fX+bEhLyfAObXAQdzo1fC/Nf/ny03jQ1XU
# bPJggV/n0MGgLD6+sYKurHEmdYepsMqXLDXL6EnD5wZq1jRX/c9ISLbCstFJL3ni
# hIWXKvJBiblO2hFdyrT0dv/EbtqHVwQWUAp6nfmeLCmz/+Ox6QfM+bwY+DjymRce
# rJDqj52+LX2b63NMXmNiFULlRLdvyYYKdHsiQ6A7oXhc6q+8eZtLLJqKEpJmwvjt
# GBqDUojPl8h3tBddb/kjLfkRfsSlC8Zo86mJ7MFnvoF3ofLPvPoF8fnViDlVEpHN
# izpYbdICSUlUb6WsQ5gJAgMBAAGjggGLMIIBhzAOBgNVHQ8BAf8EBAMCB4AwTAYD
# VR0gBEUwQzBBBgkrBgEEAaAyATIwNDAyBggrBgEFBQcCARYmaHR0cHM6Ly93d3cu
# Z2xvYmFsc2lnbi5jb20vcmVwb3NpdG9yeS8wCQYDVR0TBAIwADATBgNVHSUEDDAK
# BggrBgEFBQcDAzA+BgNVHR8ENzA1MDOgMaAvhi1odHRwOi8vY3JsLmdsb2JhbHNp
# Z24uY29tL2dzL2dzY29kZXNpZ25nMi5jcmwwgYYGCCsGAQUFBwEBBHoweDBABggr
# BgEFBQcwAoY0aHR0cDovL3NlY3VyZS5nbG9iYWxzaWduLmNvbS9jYWNlcnQvZ3Nj
# b2Rlc2lnbmcyLmNydDA0BggrBgEFBQcwAYYoaHR0cDovL29jc3AyLmdsb2JhbHNp
# Z24uY29tL2dzY29kZXNpZ25nMjAdBgNVHQ4EFgQUWhjFMoC/nYEsXezeEHlMU75h
# 1hIwHwYDVR0jBBgwFoAUCG7YtpyKv+0+18N0XcyAH6gvUHowDQYJKoZIhvcNAQEF
# BQADggEBAC2bIivs17GAdUYJHb4Uemglh2e/jq9C5tCKiBIfNUVGdUgrKqoXGB3x
# DpTZacMK9HepqjYoYVprlpAhDhbuVtIrgIOMvR1IjcSyVfC8X4dbFtfGV+4twIgV
# gVaPZrhsAcdF7ur7+DbNXRKPLunwMSeGP+jORyVLMjwgXjFktQR9pNeLXNfWirCp
# 6LX3AID7cFSpQ4PBD7BTiwQpWwcE0MX/9+S4HzCHZt7lOnF9P0J4B/NEyLTgqlzU
# f4P9pelL4iSUNkulu1H7E/sehx1nuRMLWSiqMnLnLWzKYVm3C+vykWNutJpFuFOb
# evcUoXLCGtEPU2U9AIRNNMgGPYAfmPoxggIIMIICBAIBATBnMFExCzAJBgNVBAYT
# AkJFMRkwFwYDVQQKExBHbG9iYWxTaWduIG52LXNhMScwJQYDVQQDEx5HbG9iYWxT
# aWduIENvZGVTaWduaW5nIENBIC0gRzICEhEhgRHIVRSSPqWDOYM3PJqFpzAJBgUr
# DgMCGgUAoHgwGAYKKwYBBAGCNwIBDDEKMAigAoAAoQKAADAZBgkqhkiG9w0BCQMx
# DAYKKwYBBAGCNwIBBDAcBgorBgEEAYI3AgELMQ4wDAYKKwYBBAGCNwIBFTAjBgkq
# hkiG9w0BCQQxFgQUpt0/C1jOZ89DkcmF4J5Js4a5CA0wDQYJKoZIhvcNAQEBBQAE
# ggEAalfJGPgEqfJNbDiEYN54PB1i6QCNjliA0ItU2iZ/IB1eYlbp50pD6T9CppjB
# 1wfUb7VPaomBFq/jSmFnblk8kqTmVk5k5TEVYCHBlzIey/WGqVZk3/red/PL+fnn
# LGKxErqsSwYtR3ZR9n6X1SIdwQf4FDei4FR3Xp7C3DWkBY6rl1hcfPkkfMK98FQp
# fEuTDJK3swCSn1Q1z1Lqrf9rRE+1s4IMZODEG9d6l0NJ7KAXMGux8YEC+4l+7kVB
# hoT/SSlvw9oN+FgvJlR3VC8GcfBjDo/wvCGFY++RFaxqXpg3BFhppTr5/gt99M3B
# KlpI5INw+NSkQa6msDB/Ayg62A==
# SIG # End signature block
