﻿# Import NAV CmdLets on remote machine and update folders
function Install-KBRemotely
{
    [CmdletBinding()]
    param (
        [parameter(Mandatory=$true)]
        [string] $KBRemoteDirectory,

        [parameter(Mandatory=$true)]
        [string] $MageExeRemoteLocation,

        [parameter(Mandatory=$true)]
        [string] $CmdLetsRemoteDirectory,

        [parameter(Mandatory=$false)]
        [string] $ClickOnceDeploymentFolder = 'c:\inetpub',

        [parameter(Mandatory=$true)]
        [System.Management.Automation.Runspaces.PSSession] $Session                    
    )
    PROCESS {
    
    $ManifestList = Invoke-Command -Session $Session -ScriptBlock {
        param([string] $ModulePath, [string] $NavModulePath, [string] $KBFolder, [string] $ClickOnceFolder, [string] $MageRemoteLocation, [string] $verbosePreference)
        $VerbosePreference = $verbosePreference
        Set-ExecutionPolicy -ExecutionPolicy RemoteSigned 
        Import-Module $ModulePath
        Import-Module $NavModulePath
        $Global:MageExeFile = $MageRemoteLocation
        $Global:localFilePath = [System.IO.Path]::GetTempFileName()

        Write-Verbose "Getting list of running Server Intances..."
        # Stop NAV Instances
        $RunningInstances = Get-NAVServerInstance | Where-Object { $_.State -eq "Running" }
        Write-Verbose "Stopping Server Instances..."
        Get-NAVServerInstance | Where-Object { $_.State -eq "Running" } | Set-NAVServerInstance -Stop
	    Start-Sleep -s 5
        Write-Verbose "Updating NAV Server Files from $KBFolder..."
        Copy-NavServerKB -KBDirectory $KBFolder
        Write-Verbose "Updating NAV Client Files from $KBFolder..."
        Copy-NavClientKB -KBDirectory $KBFolder
        Write-Verbose "Updating NAV ADCS Files from $KBFolder..."
        Copy-NavADCSKB -KBDirectory $KBFolder
        Write-Verbose "Updating Outlook 14 Files from $KBFolder..."
        Copy-NavOutlook14KB -KBDirectory $KBFolder
        Write-Verbose "Updating Outlook 15 Files from $KBFolder..."
        Copy-NavOutlook15KB -KBDirectory $KBFolder
        Write-Verbose "Updating NAV Web Client Files from $KBFolder..."
        Copy-NavWebClientKB -KBDirectory $KBFolder
        Write-Verbose "Updating ClickOnce Files from $ClickOnceFolder..."
        Update-NavClickOnceKB -UseRemoteSigning $true -UpdateDeployment $false -UpdateApplicationVersion $true -navClickOnceDirectory $ClickOnceFolder
        
        Write-Verbose "Done updating files..."
        foreach ($RunningInstance in $RunningInstances)
        {
            $InstanceName = $RunningInstance.ServerInstance.ToString()
            Write-Verbose "Starting Server Instance $InstanceName"
            Get-NAVServerInstance -ServerInstance $InstanceName | Set-NAVServerInstance -Start
        }

        if ((Get-Content $Global:localFilePath).Length -eq 0)
        {
            return ""
        }
        else
        {
            return $Global:localFilePath
        }

    } -ArgumentList `
        (Join-Path $CmdLetsRemoteDirectory 'NAVUpdateTools.psm1'), `
        (Join-Path $CmdLetsRemoteDirectory 'NAVPowerShell\Microsoft.Dynamics.Nav.Management.dll'), `
        $KBRemoteDirectory, `
        $ClickOnceDeploymentFolder, `
        $MageExeRemoteLocation, `
        $VerbosePreference
       
    return $ManifestList
    }
}
Export-ModuleMember -Function Install-KBRemotely

# SIG # Begin signature block
# MIILrwYJKoZIhvcNAQcCoIILoDCCC5wCAQExCzAJBgUrDgMCGgUAMGkGCisGAQQB
# gjcCAQSgWzBZMDQGCisGAQQBgjcCAR4wJgIDAQAABBAfzDtgWUsITrck0sYpfvNR
# AgEAAgEAAgEAAgEAAgEAMCEwCQYFKw4DAhoFAAQUTzw/mQ/OI8b17cK8M083mwPl
# EQ6gggkRMIIEKDCCAxCgAwIBAgILBAAAAAABL07hNVwwDQYJKoZIhvcNAQEFBQAw
# VzELMAkGA1UEBhMCQkUxGTAXBgNVBAoTEEdsb2JhbFNpZ24gbnYtc2ExEDAOBgNV
# BAsTB1Jvb3QgQ0ExGzAZBgNVBAMTEkdsb2JhbFNpZ24gUm9vdCBDQTAeFw0xMTA0
# MTMxMDAwMDBaFw0xOTA0MTMxMDAwMDBaMFExCzAJBgNVBAYTAkJFMRkwFwYDVQQK
# ExBHbG9iYWxTaWduIG52LXNhMScwJQYDVQQDEx5HbG9iYWxTaWduIENvZGVTaWdu
# aW5nIENBIC0gRzIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCyTxTn
# EL7XJnKrNpfvU79ChF5Y0Yoo/ENGb34oRFALdV0A1zwKRJ4gaqT3RUo3YKNuPxL6
# bfq2RsNqo7gMJygCVyjRUPdhOVW4w+ElhlI8vwUd17Oa+JokMUnVoqni05GrPjxz
# 7/Yp8cg10DB7f06SpQaPh+LO9cFjZqwYaSrBXrta6G6V/zuAYp2Zx8cvZtX9YhqC
# VVrG+kB3jskwPBvw8jW4bFmc/enWyrRAHvcEytFnqXTjpQhU2YM1O46MIwx1tt6G
# Sp4aPgpQSTic0qiQv5j6yIwrJxF+KvvO3qmuOJMi+qbs+1xhdsNE1swMfi9tBoCi
# dEC7tx/0O9dzVB/zAgMBAAGjgfowgfcwDgYDVR0PAQH/BAQDAgEGMBIGA1UdEwEB
# /wQIMAYBAf8CAQAwHQYDVR0OBBYEFAhu2Lacir/tPtfDdF3MgB+oL1B6MEcGA1Ud
# IARAMD4wPAYEVR0gADA0MDIGCCsGAQUFBwIBFiZodHRwczovL3d3dy5nbG9iYWxz
# aWduLmNvbS9yZXBvc2l0b3J5LzAzBgNVHR8ELDAqMCigJqAkhiJodHRwOi8vY3Js
# Lmdsb2JhbHNpZ24ubmV0L3Jvb3QuY3JsMBMGA1UdJQQMMAoGCCsGAQUFBwMDMB8G
# A1UdIwQYMBaAFGB7ZhpFDZfKiVAvfQTNNKj//P1LMA0GCSqGSIb3DQEBBQUAA4IB
# AQAiXMXdPfQLcNjj9efFjgkBu7GWNlxaB63HqERJUSV6rg2kGTuSnM+5Qia7O2yX
# 58fOEW1okdqNbfFTTVQ4jGHzyIJ2ab6BMgsxw2zJniAKWC/wSP5+SAeq10NYlHNU
# BDGpeA07jLBwwT1+170vKsPi9Y8MkNxrpci+aF5dbfh40r5JlR4VeAiR+zTIvoSt
# vODG3Rjb88rwe8IUPBi4A7qVPiEeP2Bpen9qA56NSvnwKCwwhF7sJnJCsW3LZMMS
# jNaES2dBfLEDF3gJ462otpYtpH6AA0+I98FrWkYVzSwZi9hwnOUtSYhgcqikGVJw
# Q17a1kYDsGgOJO9K9gslJO8kMIIE4TCCA8mgAwIBAgISESGBEchVFJI+pYM5gzc8
# moWnMA0GCSqGSIb3DQEBBQUAMFExCzAJBgNVBAYTAkJFMRkwFwYDVQQKExBHbG9i
# YWxTaWduIG52LXNhMScwJQYDVQQDEx5HbG9iYWxTaWduIENvZGVTaWduaW5nIENB
# IC0gRzIwHhcNMTQwMjI2MTUyOTM3WhcNMTUwMjI3MTUyOTM3WjB3MQswCQYDVQQG
# EwJJUzESMBAGA1UECBMJUmV5a2phdmlrMRIwEAYDVQQHEwlSZXlramF2aWsxEDAO
# BgNVBAoTB0FkdmFuaWExHDAaBgNVBAsTE0R5bmFtaWNzIE5hdiBUaHJvdW4xEDAO
# BgNVBAMTB0FkdmFuaWEwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDT
# fStE3keO1451Z+7xOdF8us3flCiSj9fX+bEhLyfAObXAQdzo1fC/Nf/ny03jQ1XU
# bPJggV/n0MGgLD6+sYKurHEmdYepsMqXLDXL6EnD5wZq1jRX/c9ISLbCstFJL3ni
# hIWXKvJBiblO2hFdyrT0dv/EbtqHVwQWUAp6nfmeLCmz/+Ox6QfM+bwY+DjymRce
# rJDqj52+LX2b63NMXmNiFULlRLdvyYYKdHsiQ6A7oXhc6q+8eZtLLJqKEpJmwvjt
# GBqDUojPl8h3tBddb/kjLfkRfsSlC8Zo86mJ7MFnvoF3ofLPvPoF8fnViDlVEpHN
# izpYbdICSUlUb6WsQ5gJAgMBAAGjggGLMIIBhzAOBgNVHQ8BAf8EBAMCB4AwTAYD
# VR0gBEUwQzBBBgkrBgEEAaAyATIwNDAyBggrBgEFBQcCARYmaHR0cHM6Ly93d3cu
# Z2xvYmFsc2lnbi5jb20vcmVwb3NpdG9yeS8wCQYDVR0TBAIwADATBgNVHSUEDDAK
# BggrBgEFBQcDAzA+BgNVHR8ENzA1MDOgMaAvhi1odHRwOi8vY3JsLmdsb2JhbHNp
# Z24uY29tL2dzL2dzY29kZXNpZ25nMi5jcmwwgYYGCCsGAQUFBwEBBHoweDBABggr
# BgEFBQcwAoY0aHR0cDovL3NlY3VyZS5nbG9iYWxzaWduLmNvbS9jYWNlcnQvZ3Nj
# b2Rlc2lnbmcyLmNydDA0BggrBgEFBQcwAYYoaHR0cDovL29jc3AyLmdsb2JhbHNp
# Z24uY29tL2dzY29kZXNpZ25nMjAdBgNVHQ4EFgQUWhjFMoC/nYEsXezeEHlMU75h
# 1hIwHwYDVR0jBBgwFoAUCG7YtpyKv+0+18N0XcyAH6gvUHowDQYJKoZIhvcNAQEF
# BQADggEBAC2bIivs17GAdUYJHb4Uemglh2e/jq9C5tCKiBIfNUVGdUgrKqoXGB3x
# DpTZacMK9HepqjYoYVprlpAhDhbuVtIrgIOMvR1IjcSyVfC8X4dbFtfGV+4twIgV
# gVaPZrhsAcdF7ur7+DbNXRKPLunwMSeGP+jORyVLMjwgXjFktQR9pNeLXNfWirCp
# 6LX3AID7cFSpQ4PBD7BTiwQpWwcE0MX/9+S4HzCHZt7lOnF9P0J4B/NEyLTgqlzU
# f4P9pelL4iSUNkulu1H7E/sehx1nuRMLWSiqMnLnLWzKYVm3C+vykWNutJpFuFOb
# evcUoXLCGtEPU2U9AIRNNMgGPYAfmPoxggIIMIICBAIBATBnMFExCzAJBgNVBAYT
# AkJFMRkwFwYDVQQKExBHbG9iYWxTaWduIG52LXNhMScwJQYDVQQDEx5HbG9iYWxT
# aWduIENvZGVTaWduaW5nIENBIC0gRzICEhEhgRHIVRSSPqWDOYM3PJqFpzAJBgUr
# DgMCGgUAoHgwGAYKKwYBBAGCNwIBDDEKMAigAoAAoQKAADAZBgkqhkiG9w0BCQMx
# DAYKKwYBBAGCNwIBBDAcBgorBgEEAYI3AgELMQ4wDAYKKwYBBAGCNwIBFTAjBgkq
# hkiG9w0BCQQxFgQUN3OObHvvtgOpJLZAEAxn8G12DlYwDQYJKoZIhvcNAQEBBQAE
# ggEAE/dMw7sDEapVumACXMv7ARrQv2T0qXvq62J4cgU+SD1QOEaObG840JcQncBr
# tOntHYvP1lMjPr+3IW6aAgbXJ0sF6TiLrGxSev+r2+Ar3zd39BrFW9UHayn7WMr7
# ra13nmPFx7GCnZ6oZzNIUWvloavffD7cmz2XzadaKHEIHJf0GkwzgsncGS5OIm4k
# v1pOvVPToHQMzy9uyq8NfgPMakyKjD0hv505O8RfFEayQPtZvQV5ZdeEzjuGDnVx
# DvWb+vX8wKeQgMwkMclK4UnFjzfx9RZxmbOUdXomUwVTPvZ6AeUX/Fuyjlbr3Ykg
# GQYaT1zPIAvyqkkqtz796jplcg==
# SIG # End signature block
