﻿function Update-ManifestListRemotely
{
    [CmdletBinding()]
    param (
        [parameter(Mandatory=$true,ValueFromPipeline=$true)]
        [string] $ManifestList = '', 
           
        [parameter(Mandatory=$true,ValueFromPipeline=$true)]
        [string] $CodeSigningPfxFile,

        [parameter(Mandatory=$true,ValueFromPipeline=$true)]
        [string] $CodeSigningPfxPassword,

        [parameter(Mandatory=$true)]
        [string] $MageExeLocation,

        [parameter(Mandatory=$true)]
        [System.Management.Automation.Runspaces.PSSession] $Session                    
    )
    PROCESS {
        if (($ManifestList -eq $null) -or ($ManifestList -eq ''))
        {
            Write-Verbose "Nothing to sign..."
            return
        }
        # Copy locally
        $localFile = [System.IO.Path]::GetTempFileName()
        Copy-FileFromRemoteMachine -RemoteSourceFile $ManifestList -LocalDestinationFile $localFile -Session $Session
        Write-Verbose "Manifest file copied to $localFile..."
        [System.Security.SecureString]$clickOnceCodeSigningPfxPasswordAsSecureString = $null
        if ($CodeSigningPfxPassword)
        {
            $clickOnceCodeSigningPfxPasswordAsSecureString = ConvertTo-SecureString $CodeSigningPfxPassword -AsPlainText -Force
        }
        Write-Verbose "Reading Manifest list from $localFile..."
        $ManifestFiles = Get-Content $localFile
        foreach ($ManifestFile in $ManifestFiles)
        {
            if ($ManifestFile -ne "")
            {
                Write-Verbose "Signing file $manifestFile..."
                Set-ManifestSignatureRemotely `
                    -ManifestFile $ManifestFile `
                    -CodeSigningPfxFile $CodeSigningPfxFile `
                    -CodeSigningPfxPassword $clickOnceCodeSigningPfxPasswordAsSecureString `
                    -MageExeLocation $MageExeLocation `
                    -Session $Session 
            }

        }        
    }
}
Export-ModuleMember -Function Update-ManifestListRemotely
# SIG # Begin signature block
# MIILrwYJKoZIhvcNAQcCoIILoDCCC5wCAQExCzAJBgUrDgMCGgUAMGkGCisGAQQB
# gjcCAQSgWzBZMDQGCisGAQQBgjcCAR4wJgIDAQAABBAfzDtgWUsITrck0sYpfvNR
# AgEAAgEAAgEAAgEAAgEAMCEwCQYFKw4DAhoFAAQUMz2VjfvYCiQgp4WNzn8KV5lI
# +nGgggkRMIIEKDCCAxCgAwIBAgILBAAAAAABL07hNVwwDQYJKoZIhvcNAQEFBQAw
# VzELMAkGA1UEBhMCQkUxGTAXBgNVBAoTEEdsb2JhbFNpZ24gbnYtc2ExEDAOBgNV
# BAsTB1Jvb3QgQ0ExGzAZBgNVBAMTEkdsb2JhbFNpZ24gUm9vdCBDQTAeFw0xMTA0
# MTMxMDAwMDBaFw0xOTA0MTMxMDAwMDBaMFExCzAJBgNVBAYTAkJFMRkwFwYDVQQK
# ExBHbG9iYWxTaWduIG52LXNhMScwJQYDVQQDEx5HbG9iYWxTaWduIENvZGVTaWdu
# aW5nIENBIC0gRzIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCyTxTn
# EL7XJnKrNpfvU79ChF5Y0Yoo/ENGb34oRFALdV0A1zwKRJ4gaqT3RUo3YKNuPxL6
# bfq2RsNqo7gMJygCVyjRUPdhOVW4w+ElhlI8vwUd17Oa+JokMUnVoqni05GrPjxz
# 7/Yp8cg10DB7f06SpQaPh+LO9cFjZqwYaSrBXrta6G6V/zuAYp2Zx8cvZtX9YhqC
# VVrG+kB3jskwPBvw8jW4bFmc/enWyrRAHvcEytFnqXTjpQhU2YM1O46MIwx1tt6G
# Sp4aPgpQSTic0qiQv5j6yIwrJxF+KvvO3qmuOJMi+qbs+1xhdsNE1swMfi9tBoCi
# dEC7tx/0O9dzVB/zAgMBAAGjgfowgfcwDgYDVR0PAQH/BAQDAgEGMBIGA1UdEwEB
# /wQIMAYBAf8CAQAwHQYDVR0OBBYEFAhu2Lacir/tPtfDdF3MgB+oL1B6MEcGA1Ud
# IARAMD4wPAYEVR0gADA0MDIGCCsGAQUFBwIBFiZodHRwczovL3d3dy5nbG9iYWxz
# aWduLmNvbS9yZXBvc2l0b3J5LzAzBgNVHR8ELDAqMCigJqAkhiJodHRwOi8vY3Js
# Lmdsb2JhbHNpZ24ubmV0L3Jvb3QuY3JsMBMGA1UdJQQMMAoGCCsGAQUFBwMDMB8G
# A1UdIwQYMBaAFGB7ZhpFDZfKiVAvfQTNNKj//P1LMA0GCSqGSIb3DQEBBQUAA4IB
# AQAiXMXdPfQLcNjj9efFjgkBu7GWNlxaB63HqERJUSV6rg2kGTuSnM+5Qia7O2yX
# 58fOEW1okdqNbfFTTVQ4jGHzyIJ2ab6BMgsxw2zJniAKWC/wSP5+SAeq10NYlHNU
# BDGpeA07jLBwwT1+170vKsPi9Y8MkNxrpci+aF5dbfh40r5JlR4VeAiR+zTIvoSt
# vODG3Rjb88rwe8IUPBi4A7qVPiEeP2Bpen9qA56NSvnwKCwwhF7sJnJCsW3LZMMS
# jNaES2dBfLEDF3gJ462otpYtpH6AA0+I98FrWkYVzSwZi9hwnOUtSYhgcqikGVJw
# Q17a1kYDsGgOJO9K9gslJO8kMIIE4TCCA8mgAwIBAgISESGBEchVFJI+pYM5gzc8
# moWnMA0GCSqGSIb3DQEBBQUAMFExCzAJBgNVBAYTAkJFMRkwFwYDVQQKExBHbG9i
# YWxTaWduIG52LXNhMScwJQYDVQQDEx5HbG9iYWxTaWduIENvZGVTaWduaW5nIENB
# IC0gRzIwHhcNMTQwMjI2MTUyOTM3WhcNMTUwMjI3MTUyOTM3WjB3MQswCQYDVQQG
# EwJJUzESMBAGA1UECBMJUmV5a2phdmlrMRIwEAYDVQQHEwlSZXlramF2aWsxEDAO
# BgNVBAoTB0FkdmFuaWExHDAaBgNVBAsTE0R5bmFtaWNzIE5hdiBUaHJvdW4xEDAO
# BgNVBAMTB0FkdmFuaWEwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDT
# fStE3keO1451Z+7xOdF8us3flCiSj9fX+bEhLyfAObXAQdzo1fC/Nf/ny03jQ1XU
# bPJggV/n0MGgLD6+sYKurHEmdYepsMqXLDXL6EnD5wZq1jRX/c9ISLbCstFJL3ni
# hIWXKvJBiblO2hFdyrT0dv/EbtqHVwQWUAp6nfmeLCmz/+Ox6QfM+bwY+DjymRce
# rJDqj52+LX2b63NMXmNiFULlRLdvyYYKdHsiQ6A7oXhc6q+8eZtLLJqKEpJmwvjt
# GBqDUojPl8h3tBddb/kjLfkRfsSlC8Zo86mJ7MFnvoF3ofLPvPoF8fnViDlVEpHN
# izpYbdICSUlUb6WsQ5gJAgMBAAGjggGLMIIBhzAOBgNVHQ8BAf8EBAMCB4AwTAYD
# VR0gBEUwQzBBBgkrBgEEAaAyATIwNDAyBggrBgEFBQcCARYmaHR0cHM6Ly93d3cu
# Z2xvYmFsc2lnbi5jb20vcmVwb3NpdG9yeS8wCQYDVR0TBAIwADATBgNVHSUEDDAK
# BggrBgEFBQcDAzA+BgNVHR8ENzA1MDOgMaAvhi1odHRwOi8vY3JsLmdsb2JhbHNp
# Z24uY29tL2dzL2dzY29kZXNpZ25nMi5jcmwwgYYGCCsGAQUFBwEBBHoweDBABggr
# BgEFBQcwAoY0aHR0cDovL3NlY3VyZS5nbG9iYWxzaWduLmNvbS9jYWNlcnQvZ3Nj
# b2Rlc2lnbmcyLmNydDA0BggrBgEFBQcwAYYoaHR0cDovL29jc3AyLmdsb2JhbHNp
# Z24uY29tL2dzY29kZXNpZ25nMjAdBgNVHQ4EFgQUWhjFMoC/nYEsXezeEHlMU75h
# 1hIwHwYDVR0jBBgwFoAUCG7YtpyKv+0+18N0XcyAH6gvUHowDQYJKoZIhvcNAQEF
# BQADggEBAC2bIivs17GAdUYJHb4Uemglh2e/jq9C5tCKiBIfNUVGdUgrKqoXGB3x
# DpTZacMK9HepqjYoYVprlpAhDhbuVtIrgIOMvR1IjcSyVfC8X4dbFtfGV+4twIgV
# gVaPZrhsAcdF7ur7+DbNXRKPLunwMSeGP+jORyVLMjwgXjFktQR9pNeLXNfWirCp
# 6LX3AID7cFSpQ4PBD7BTiwQpWwcE0MX/9+S4HzCHZt7lOnF9P0J4B/NEyLTgqlzU
# f4P9pelL4iSUNkulu1H7E/sehx1nuRMLWSiqMnLnLWzKYVm3C+vykWNutJpFuFOb
# evcUoXLCGtEPU2U9AIRNNMgGPYAfmPoxggIIMIICBAIBATBnMFExCzAJBgNVBAYT
# AkJFMRkwFwYDVQQKExBHbG9iYWxTaWduIG52LXNhMScwJQYDVQQDEx5HbG9iYWxT
# aWduIENvZGVTaWduaW5nIENBIC0gRzICEhEhgRHIVRSSPqWDOYM3PJqFpzAJBgUr
# DgMCGgUAoHgwGAYKKwYBBAGCNwIBDDEKMAigAoAAoQKAADAZBgkqhkiG9w0BCQMx
# DAYKKwYBBAGCNwIBBDAcBgorBgEEAYI3AgELMQ4wDAYKKwYBBAGCNwIBFTAjBgkq
# hkiG9w0BCQQxFgQUxlHZOJ7XGwH5onYhXkAFDAynzP4wDQYJKoZIhvcNAQEBBQAE
# ggEAVNu3Y5M5XfkyPjY2ie/Zfm7Z19zvh+THturkSnjZbcoyQ7CMDxblIsFbz/+d
# kioQfVjrb969FxLkSIZAZZNaT5HZZkmbeAziKxh/R5W2Fsxk6yd7Xz2jkvr/tZb8
# UmClTd6jBRNMGlNqRYZvQiPjeY7LTByQqOsiCeptuEn7J00L8txUiHirvFK946do
# CT7Y5F7qwRlUH1Ezt/GOlhKg6OE6qV6ewRB4L3r2Se8lPT3afdxNauB2BySPQ3CS
# 9ku6pvG8oFaECj3nfFYK8zQYHcXXZO+gYWS4tvbWx7AiOfSfesA2a6+3FFQDru1J
# Ks6SmzxPJCUux/5/dhn0AkVVsw==
# SIG # End signature block
