﻿function New-DatabaseFromCRONUSBackup
{
    [CmdletBinding()]
    param ( 
        [parameter(Mandatory=$false)]
        [string]$Servername = 'localhost',
        [parameter(Mandatory=$true)]
        [string]$BackupFile,
        [parameter(Mandatory=$false)]
        [string]$DataDestinationFolder = '',
        [parameter(Mandatory=$false)]
        [string]$LogDestinationFolder = '',
        [parameter(Mandatory=$true)]
        [string]$DatabaseName,
        [parameter(Mandatory=$false)]
        [boolean]$ReplaceDatabase = $false,
        [parameter(Mandatory=$false)]
        [string]$DataOrigName = 'Demo Database NAV (7-1)_Data',
        [parameter(Mandatory=$false)]
        [string]$LogOrigName = 'Demo Database NAV (7-1)_Log',
        [parameter(Mandatory=$false)]
        [string]$NewDbOwner = ''

    )
    PROCESS {
    #Load the DLLs if not using SQLPS 
    [System.Reflection.Assembly]::LoadWithPartialName('Microsoft.SqlServer.SMO') | out-null 
    [System.Reflection.Assembly]::LoadWithPartialName('Microsoft.SqlServer.SmoExtended') | out-null

    #load server, backup, and restore objects 
    Write-Verbose "Connecting to server $Servername..."
    $server = new-object("Microsoft.SqlServer.Management.Smo.Server") $Servername 
    $dbRestore = new-object("Microsoft.SqlServer.Management.Smo.Restore")

    #settings for the restore 
    $dbRestore.Action = "Database" 
    $dbRestore.NoRecovery = $false; 
    $dbRestore.ReplaceDatabase = $ReplaceDatabase; 
    $dbRestorePercentCompleteNotification = 5; 
    $dbRestore.Devices.AddDevice($BackupFile, [Microsoft.SqlServer.Management.Smo.DeviceType]::File)

    #get the db name 
    $dbRestoreDetails = $dbRestore.ReadBackupHeader($server)

    #print database name 
    Write-Verbose ("Database Name from Backup File : " + $dbRestoreDetails.Rows[0]["DatabaseName"])

    #give a new database name 
    Write-Verbose "Restoring to database $DatabaseName..."
    $dbRestore.Database = $DatabaseName

    #specify new data and log files (mdf and ldf) 
    if ($DataDestinationFolder -ne '')
    {
        $dbRestoreFile = new-object("Microsoft.SqlServer.Management.Smo.RelocateFile") 
        $dbRestoreFile.LogicalFileName = $DataOrigName
        $DataDestName = Join-Path $DataDestinationFolder ($DatabaseName + '.mdf')
        Write-Verbose "Relocating Data file to $DataDestName..."
        $dbRestoreFile.PhysicalFileName = $DataDestName
        $dbRestore.RelocateFiles.Add($dbRestoreFile) 
    }
    if ($LogDestinationFolder -ne '')
    {
        $dbRestoreLog = new-object("Microsoft.SqlServer.Management.Smo.RelocateFile")
        $dbRestoreLog.LogicalFileName = $LogOrigName   
        $LogDestName = Join-Path $LogDestinationFolder ($DatabaseName + '.ldf')
        Write-Verbose "Relocating Log file to $LogDestName..."
        $dbRestoreLog.PhysicalFileName = $LogDestName 
        $dbRestore.RelocateFiles.Add($dbRestoreLog)
    }
         
    #execute the restore! 
    $dbRestore.SqlRestore($server) 
    Write-Verbose "Restore of $DatabaseName Complete"

    # Create Network Service user if missing
    if ($NewDbOwner -eq "")
    {
        Write-Verbose "Creating login 'NT AUTHORITY\NETWORK SERVICE'..."
        New-DatabaseOwner -ServerName $ServerName -DatabaseName $DatabaseName -NewDbOwner 'NT AUTHORITY\NETWORK SERVICE'
    }
    else
    {
        Write-Verbose "Creating login '$NewDbOwner'..."
        New-DatabaseOwner -ServerName $ServerName -DatabaseName $DatabaseName -NewDbOwner $NewDbOwner
    }
    }
}
Export-ModuleMember -Function New-DatabaseFromCRONUSBackup

# SIG # Begin signature block
# MIILrwYJKoZIhvcNAQcCoIILoDCCC5wCAQExCzAJBgUrDgMCGgUAMGkGCisGAQQB
# gjcCAQSgWzBZMDQGCisGAQQBgjcCAR4wJgIDAQAABBAfzDtgWUsITrck0sYpfvNR
# AgEAAgEAAgEAAgEAAgEAMCEwCQYFKw4DAhoFAAQUOAX/CuI197McTwoApclwhIEI
# q7igggkRMIIEKDCCAxCgAwIBAgILBAAAAAABL07hNVwwDQYJKoZIhvcNAQEFBQAw
# VzELMAkGA1UEBhMCQkUxGTAXBgNVBAoTEEdsb2JhbFNpZ24gbnYtc2ExEDAOBgNV
# BAsTB1Jvb3QgQ0ExGzAZBgNVBAMTEkdsb2JhbFNpZ24gUm9vdCBDQTAeFw0xMTA0
# MTMxMDAwMDBaFw0xOTA0MTMxMDAwMDBaMFExCzAJBgNVBAYTAkJFMRkwFwYDVQQK
# ExBHbG9iYWxTaWduIG52LXNhMScwJQYDVQQDEx5HbG9iYWxTaWduIENvZGVTaWdu
# aW5nIENBIC0gRzIwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCyTxTn
# EL7XJnKrNpfvU79ChF5Y0Yoo/ENGb34oRFALdV0A1zwKRJ4gaqT3RUo3YKNuPxL6
# bfq2RsNqo7gMJygCVyjRUPdhOVW4w+ElhlI8vwUd17Oa+JokMUnVoqni05GrPjxz
# 7/Yp8cg10DB7f06SpQaPh+LO9cFjZqwYaSrBXrta6G6V/zuAYp2Zx8cvZtX9YhqC
# VVrG+kB3jskwPBvw8jW4bFmc/enWyrRAHvcEytFnqXTjpQhU2YM1O46MIwx1tt6G
# Sp4aPgpQSTic0qiQv5j6yIwrJxF+KvvO3qmuOJMi+qbs+1xhdsNE1swMfi9tBoCi
# dEC7tx/0O9dzVB/zAgMBAAGjgfowgfcwDgYDVR0PAQH/BAQDAgEGMBIGA1UdEwEB
# /wQIMAYBAf8CAQAwHQYDVR0OBBYEFAhu2Lacir/tPtfDdF3MgB+oL1B6MEcGA1Ud
# IARAMD4wPAYEVR0gADA0MDIGCCsGAQUFBwIBFiZodHRwczovL3d3dy5nbG9iYWxz
# aWduLmNvbS9yZXBvc2l0b3J5LzAzBgNVHR8ELDAqMCigJqAkhiJodHRwOi8vY3Js
# Lmdsb2JhbHNpZ24ubmV0L3Jvb3QuY3JsMBMGA1UdJQQMMAoGCCsGAQUFBwMDMB8G
# A1UdIwQYMBaAFGB7ZhpFDZfKiVAvfQTNNKj//P1LMA0GCSqGSIb3DQEBBQUAA4IB
# AQAiXMXdPfQLcNjj9efFjgkBu7GWNlxaB63HqERJUSV6rg2kGTuSnM+5Qia7O2yX
# 58fOEW1okdqNbfFTTVQ4jGHzyIJ2ab6BMgsxw2zJniAKWC/wSP5+SAeq10NYlHNU
# BDGpeA07jLBwwT1+170vKsPi9Y8MkNxrpci+aF5dbfh40r5JlR4VeAiR+zTIvoSt
# vODG3Rjb88rwe8IUPBi4A7qVPiEeP2Bpen9qA56NSvnwKCwwhF7sJnJCsW3LZMMS
# jNaES2dBfLEDF3gJ462otpYtpH6AA0+I98FrWkYVzSwZi9hwnOUtSYhgcqikGVJw
# Q17a1kYDsGgOJO9K9gslJO8kMIIE4TCCA8mgAwIBAgISESGBEchVFJI+pYM5gzc8
# moWnMA0GCSqGSIb3DQEBBQUAMFExCzAJBgNVBAYTAkJFMRkwFwYDVQQKExBHbG9i
# YWxTaWduIG52LXNhMScwJQYDVQQDEx5HbG9iYWxTaWduIENvZGVTaWduaW5nIENB
# IC0gRzIwHhcNMTQwMjI2MTUyOTM3WhcNMTUwMjI3MTUyOTM3WjB3MQswCQYDVQQG
# EwJJUzESMBAGA1UECBMJUmV5a2phdmlrMRIwEAYDVQQHEwlSZXlramF2aWsxEDAO
# BgNVBAoTB0FkdmFuaWExHDAaBgNVBAsTE0R5bmFtaWNzIE5hdiBUaHJvdW4xEDAO
# BgNVBAMTB0FkdmFuaWEwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDT
# fStE3keO1451Z+7xOdF8us3flCiSj9fX+bEhLyfAObXAQdzo1fC/Nf/ny03jQ1XU
# bPJggV/n0MGgLD6+sYKurHEmdYepsMqXLDXL6EnD5wZq1jRX/c9ISLbCstFJL3ni
# hIWXKvJBiblO2hFdyrT0dv/EbtqHVwQWUAp6nfmeLCmz/+Ox6QfM+bwY+DjymRce
# rJDqj52+LX2b63NMXmNiFULlRLdvyYYKdHsiQ6A7oXhc6q+8eZtLLJqKEpJmwvjt
# GBqDUojPl8h3tBddb/kjLfkRfsSlC8Zo86mJ7MFnvoF3ofLPvPoF8fnViDlVEpHN
# izpYbdICSUlUb6WsQ5gJAgMBAAGjggGLMIIBhzAOBgNVHQ8BAf8EBAMCB4AwTAYD
# VR0gBEUwQzBBBgkrBgEEAaAyATIwNDAyBggrBgEFBQcCARYmaHR0cHM6Ly93d3cu
# Z2xvYmFsc2lnbi5jb20vcmVwb3NpdG9yeS8wCQYDVR0TBAIwADATBgNVHSUEDDAK
# BggrBgEFBQcDAzA+BgNVHR8ENzA1MDOgMaAvhi1odHRwOi8vY3JsLmdsb2JhbHNp
# Z24uY29tL2dzL2dzY29kZXNpZ25nMi5jcmwwgYYGCCsGAQUFBwEBBHoweDBABggr
# BgEFBQcwAoY0aHR0cDovL3NlY3VyZS5nbG9iYWxzaWduLmNvbS9jYWNlcnQvZ3Nj
# b2Rlc2lnbmcyLmNydDA0BggrBgEFBQcwAYYoaHR0cDovL29jc3AyLmdsb2JhbHNp
# Z24uY29tL2dzY29kZXNpZ25nMjAdBgNVHQ4EFgQUWhjFMoC/nYEsXezeEHlMU75h
# 1hIwHwYDVR0jBBgwFoAUCG7YtpyKv+0+18N0XcyAH6gvUHowDQYJKoZIhvcNAQEF
# BQADggEBAC2bIivs17GAdUYJHb4Uemglh2e/jq9C5tCKiBIfNUVGdUgrKqoXGB3x
# DpTZacMK9HepqjYoYVprlpAhDhbuVtIrgIOMvR1IjcSyVfC8X4dbFtfGV+4twIgV
# gVaPZrhsAcdF7ur7+DbNXRKPLunwMSeGP+jORyVLMjwgXjFktQR9pNeLXNfWirCp
# 6LX3AID7cFSpQ4PBD7BTiwQpWwcE0MX/9+S4HzCHZt7lOnF9P0J4B/NEyLTgqlzU
# f4P9pelL4iSUNkulu1H7E/sehx1nuRMLWSiqMnLnLWzKYVm3C+vykWNutJpFuFOb
# evcUoXLCGtEPU2U9AIRNNMgGPYAfmPoxggIIMIICBAIBATBnMFExCzAJBgNVBAYT
# AkJFMRkwFwYDVQQKExBHbG9iYWxTaWduIG52LXNhMScwJQYDVQQDEx5HbG9iYWxT
# aWduIENvZGVTaWduaW5nIENBIC0gRzICEhEhgRHIVRSSPqWDOYM3PJqFpzAJBgUr
# DgMCGgUAoHgwGAYKKwYBBAGCNwIBDDEKMAigAoAAoQKAADAZBgkqhkiG9w0BCQMx
# DAYKKwYBBAGCNwIBBDAcBgorBgEEAYI3AgELMQ4wDAYKKwYBBAGCNwIBFTAjBgkq
# hkiG9w0BCQQxFgQUt0Y1D8v6LIlOkpbwQ5sUP/HD0lAwDQYJKoZIhvcNAQEBBQAE
# ggEAjvWstRXrM0s7vnPMmsI/hKzQ6hN0RH5SG/RGJpneKwyQXZ9cKgwRat7p2Lun
# I5dwmBo6anZjmnz9f96OJNNg8dALEhM0ktp8Wq6uFY5ANnc/Cr3OIkb3vaaW61aD
# XFsYqI7DsCrdd7bx568LOFkMZtXZfDlYN+LiC/fXYGK/ytyS8nrEjFMu9ldbRLO6
# 8q93iZgWOeuP5TFxSib9WIkNqGiQqhEdZiLKKaCd5VzEAttm4VwPYpTldQD/Y8sj
# hDHE9rGbsHrESlhCFLBpKjubiZQ6gtSRUU+syS29X+xOhgGOnzKkZPDCAWJcVXxY
# tVbb82/UpefVxitkMZ/XgSHM8A==
# SIG # End signature block
